@@ -29,6 +29,7 @@ import subprocess
 from gi.repository import Gtk, GLib
 
 import psutil
+old_psutil_format = isinstance(psutil.Process.username, property)
 
 import light_locker_xfsync
 
@@ -37,6 +38,11 @@ import light_locker_xfsync
 username = GLib.get_user_name()
 
 
+screensaver_managers = {
+    'xfce4-power-manager': (_("Xfce Power Manager"), "xfce4-power-manager -c")
+}
+
+
 class LightLockerSettings:
     '''Light Locker Settings application class.'''
 
@@ -55,6 +61,7 @@ class LightLockerSettings:
             'screensaver-settings.desktop')
 
         self.builder = Gtk.Builder()
+        self.builder.set_translation_domain ('light-locker-settings')
 
         script_dir = os.path.dirname(os.path.abspath(__file__))
         glade_file = os.path.join(script_dir, "light-locker-settings.glade")
@@ -63,7 +70,6 @@ class LightLockerSettings:
 
         self.window = self.builder.get_object("light_locker_settings_window")
         self.window.set_title(_("Light Locker Settings"))
-        self.window.show()
 
         ''' Set background-color of frame to base-color to make it resemble the
         XfceHeading widget '''
@@ -94,6 +100,8 @@ class LightLockerSettings:
             self.screenoff_timeout.add_mark(i * 10, 3, None)
             self.lock_delay.add_mark(i * 10, 3, None)
 
+        self.screensaver_managed = False
+
         self.init_settings()
 
         ''' Monitor changes to the settings '''
@@ -106,6 +114,8 @@ class LightLockerSettings:
         self.lock_delay.connect(
             "value-changed", self.lock_delay_value_changed_cb)
 
+        self.window.show()
+
 # Application Callbacks
     def screenblank_value_changed_cb(self, gparam):
         '''Sync screenblank and screenoff settings when values are modified.'''
@@ -188,32 +198,61 @@ class LightLockerSettings:
         Gtk.main_quit()
 
 # Process Management
-    def check_running_process(self, process_name):
-        """Return True if the specified process is active."""
-        # Find the process...
-        for pid in psutil.get_pid_list():
-            p = psutil.Process(pid)
-            if p.username == username:
-                # When found, end the light-locker process.
-                try:
-                    if os.path.basename(p.exe) == process_name:
-                        return True
-                except psutil._error.AccessDenied:
-                    pass
-        return False
+    if old_psutil_format:
+        def check_running_process(self, process_name):
+            """Return True if the specified process is active."""
+            # Find the process...
+            for pid in psutil.get_pid_list():
+                p = psutil.Process(pid)
+                if p.username == username:
+                    # When found, end the light-locker process.
+                    try:
+                        if os.path.basename(p.exe) == process_name:
+                            return True
+                    except psutil._error.AccessDenied:
+                        pass
+            return False
 
-    def stop_light_locker(self):
-        """Safely stop the light-locker process."""
-        # Find the process...
-        for pid in psutil.get_pid_list():
-            p = psutil.Process(pid)
-            if p.username == username:
-                # When found, end the light-locker process.
-                try:
-                    if os.path.basename(p.exe) == 'light-locker':
-                        p.terminate()
-                except psutil._error.AccessDenied:
-                    pass
+        def stop_light_locker(self):
+            """Safely stop the light-locker process."""
+            # Find the process...
+            for pid in psutil.get_pid_list():
+                p = psutil.Process(pid)
+                if p.username == username:
+                    # When found, end the light-locker process.
+                    try:
+                        if os.path.basename(p.exe) == 'light-locker':
+                            p.terminate()
+                    except psutil._error.AccessDenied:
+                        pass
+
+    else:
+        def check_running_process(self, process_name):
+            """Return True if the specified process is active."""
+            # Find the process...
+            for pid in psutil.get_pid_list():
+                p = psutil.Process(pid)
+                if p.username() == username:
+                    # When found, end the light-locker process.
+                    try:
+                        if os.path.basename(p.exe()) == process_name:
+                            return True
+                    except psutil.AccessDenied:
+                        pass
+            return False
+
+        def stop_light_locker(self):
+            """Safely stop the light-locker process."""
+            # Find the process...
+            for pid in psutil.get_pid_list():
+                p = psutil.Process(pid)
+                if p.username() == username:
+                    # When found, end the light-locker process.
+                    try:
+                        if os.path.basename(p.exe()) == 'light-locker':
+                            p.terminate()
+                    except psutil.AccessDenied:
+                        pass
 
     def run_command(self, cmd, check_output=False):
         '''Run a shell command, return its output.'''
@@ -221,12 +260,37 @@ class LightLockerSettings:
             return None
         if check_output:
             output = subprocess.check_output(cmd, shell=True)
+            if not isinstance(output, str):
+                output = output.decode('utf-8')
             return output
         else:
             subprocess.Popen(cmd.split(" "))
             return None
 
+    def run_command_cb(self, widget, cmd):
+        self.run_command(cmd, False)
+
 # Settings Parsing
+    def use_screensaver_manager(self, name, command):
+        """Replace the Screensaver settings with a different application."""
+        self.screensaver_managed = True
+
+        infobar = self.builder.get_object("screensaver_info")
+        infobar_label = self.builder.get_object("screensaver_info_label")
+        infobar_button = self.builder.get_object("screensaver_info_button")
+        screensaver_frame = self.builder.get_object("screensaver_details")
+
+        # Light Locker Settings is *NOT* controlling the screensaver.
+        if os.path.isfile(self.screenblank_timeout_desktop_file):
+            os.remove(self.screenblank_timeout_desktop_file)
+        screensaver_frame.hide()
+
+        # Update the InfoBar
+        infobar_label.set_label(
+            _("Your screensaver settings are managed by %s.") % name)
+        infobar_button.connect("clicked", self.run_command_cb, command)
+        infobar.show()
+
     def init_settings(self):
         # Get the Settings, first from light-locker, then override as needed
         ''' if there is a file exists in ~/.config/autostart/ parse that
@@ -234,8 +298,11 @@ class LightLockerSettings:
             systemwide '''
         if os.path.isfile(self.user_desktop_file):
             desktop_file = self.user_desktop_file
-        else:
+        elif os.path.isfile(self.systemwide_desktop_file):
             desktop_file = self.systemwide_desktop_file
+        else:
+            desktop_file = None
+
         settings = self.read_in_desktop(desktop_file)
         use_light_locker = settings['light-locker-enabled']
         lock_after_screensaver = settings['lock-after-screensaver']
@@ -245,19 +312,17 @@ class LightLockerSettings:
         screen_blank_timeout, screen_off_timeout = \
             self.get_screen_blank_timeout()
 
-        # Replace settings with xfce4-session
-        if self.check_running_process("xfce4-session"):
-            session_sync = light_locker_xfsync.XfceSessionSync()
-            lock_on_suspend = session_sync.get_lock()
-
         # Replace settings with xfce4-power-manager
         if self.check_running_process("xfce4-power-manager"):
             xfpm_sync = light_locker_xfsync.XfpmSync()
-            screen_blank_timeout, screen_off_timeout = xfpm_sync.get_dpms()
-            screen_blank_timeout = self.light_locker_time_down_scaler(
-                screen_blank_timeout)
-            screen_off_timeout = self.light_locker_time_down_scaler(
-                screen_off_timeout)
+            lock_on_suspend = xfpm_sync.get_lock()
+
+        # Check if any known screensaver managers are currently running.
+        for process_name in screensaver_managers.keys():
+            if self.check_running_process(process_name):
+                name, command = screensaver_managers[process_name]
+                self.use_screensaver_manager(name, command)
+                break
 
         # Apply the settings
         self.use_lightlocker.set_active(use_light_locker)
@@ -285,11 +350,25 @@ class LightLockerSettings:
 
     def read_in_desktop(self, filepath):
         '''Parse the .desktop file for light-locker settings.'''
-        with open(filepath) as f:
-            self.content = f.readlines()
-            for line in self.content:
-                if line.startswith("Exec="):
-                    return self.parse_options(line)
+        if filepath is not None:
+            try:
+                with open(filepath) as f:
+                    self.content = f.readlines()
+                    for line in self.content:
+                        if line.startswith("Exec="):
+                            return self.parse_options(line)
+            except:
+                pass
+
+        # Fallback if something fails.
+        self.content = "[Desktop Entry]\n" \
+                       "Type=Application\n" \
+                       "Name=Screen Locker\n" \
+                       "Comment=Launch screen locker program\n" \
+                       "Icon=preferences-desktop-screensaver\n" \
+                       "Exec=\n" \
+                       "NoDisplay=true"
+        return self.parse_options("Exec=\n")
 
     def parse_options(self, options_line):
         '''Parse command-line arguments from the Exec line.'''
@@ -456,23 +535,16 @@ class LightLockerSettings:
             session_sync = light_locker_xfsync.XfceSessionSync()
             session_sync.set_lock(lock_on_suspend)
 
-            # If xfce4-session manages locking, disable it for light-locker.
-            settings['lock-on-suspend'] = False
-
-        # If xfce4-power-manager is running, sync the DPMS settings.
+        # If xfpm manages locking, disable it for light-locker.
         if self.check_running_process("xfce4-power-manager"):
             xfpm_sync = light_locker_xfsync.XfpmSync()
-            screen_off = settings['screen-off-timeout'] / 60
-            screen_blank = settings['screen-blank-timeout'] / 60
-            xfpm_sync.set_dpms(screen_blank, screen_off)
             xfpm_sync.set_lock(lock_on_suspend)
 
-            # If xfpm manages locking, disable it for light-locker.
-            settings['lock-on-suspend'] = False
-
         # Apply the remaining settings to light-locker.
         self.apply_light_locker_settings(settings)
-        self.apply_screen_blank_settings(settings)
+
+        if not self.screensaver_managed:
+            self.apply_screen_blank_settings(settings)
 
     def apply_light_locker_settings(self, settings):
         '''Apply the light-locker settings'''
